==> one_target_mobile_sdk-0.0.19.tar.gz: ios/Classes/SwiftOneTargetMobileSdkPlugin.swift <==
import Flutter
import UIKit
//import SwiftDate
import OneTargetMobileSDK

//format codes: cmd + A then ctrl + I
public class SwiftOneTargetMobileSdkPlugin: NSObject, FlutterPlugin {
    let ENV_DEV = 1
    let ENV_STG = 2
    let ENV_PROD = 3
    
    var analytics: OneTargetAnalytics? = nil
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: Const.sdk, binaryMessenger: registrar.messenger())
        let instance = SwiftOneTargetMobileSdkPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
        case Const.getPlatformVersion:
            result("iOS " + UIDevice.current.systemVersion)
        case Const.setupTracking:
            setupTracking(call, result)
        case Const.trackEvent:
            trackEvent(call, result)
        default:
            result(nil)
        }
    }
    
    private func setupTracking(_ call: FlutterMethodCall,_ result: @escaping FlutterResult) {
        let arguments = call.arguments as! Dictionary<String, Any>
        let writeKey = arguments["writeKey"] as! String
        print("writeKey " + writeKey)
        
        let env = arguments["env"] as! Int
        print("env " + env.toString())
        var flavor = "prod"; // default prod
        if(env == ENV_DEV){
            flavor = "dev"
        }else if(env == ENV_STG){
            flavor = "stg"
        }else if(env == ENV_PROD){
            flavor = "prod"
        }
        print("flavor " + flavor)
        
        let configuration = Configuration(writeKey: writeKey, flavor: flavor)
        analytics = OneTargetAnalytics.init(configuration: configuration)
        let debugLogsEnabled = arguments["isShowLog"] as! Bool
        print("debugLogsEnabled " + debugLogsEnabled.toString())
        OneTargetAnalytics.debugLogsEnabled = debugLogsEnabled
        result(true)
    }
    
    //flavor: dev, stg
    private func trackEvent(_ call: FlutterMethodCall,_ result: @escaping FlutterResult) {
        let arguments = call.arguments as! Dictionary<String, Any>
        
        let identityId = arguments["identityId"] as! Dictionary<String, Any>
        print("identityId: \(identityId as AnyObject)")
        let profile = arguments["profile"] as! [Dictionary<String, Any>]
        print("profile: \(profile as AnyObject)")
        let eventName = arguments["eventName"] as! String
        print("eventName " + eventName)
        let eventData = arguments["eventData"] as! Dictionary<String, Any>
        print("eventData: \(eventData as AnyObject)")
        
        let outputPlugin = OutputPlugin()
        outputPlugin.result = result
        analytics?.add(plugin: outputPlugin)
        
        analytics?.trackEvent(
            identityId: identityId,
            eventName: eventName,
            eventData: eventData,
            profile: profile
        )
        
    }
    
    private func convertMilliToDate(milliseconds: Int64) -> Date {
        return Date(timeIntervalSince1970: (TimeInterval(milliseconds) / 1000))
    }
}

class OutputPlugin: Plugin {
    var analytics: OneTargetAnalytics?
    var type: PluginType = .after
    var result:FlutterResult?
    
    func execute<T>(event: T?) -> T? where T : RawEvent {
        
        let string = event?.prettyPrint() ?? ("")
        print("execute string " + string)
        
        self.result?([
            "response" : string
        ])
        
        return event
    }
}

==> one_target_mobile_sdk-0.0.22.tar.gz: ios/Classes/SwiftOneTargetMobileSdkPlugin.swift <==
import Flutter
import UIKit
//import SwiftDate
import OneTargetMobileSDK

//format codes: cmd + A then ctrl + I
public class SwiftOneTargetMobileSdkPlugin: NSObject, FlutterPlugin {
    let ENV_DEV = 1
    let ENV_STG = 2
    let ENV_PROD = 3
    
    var analytics: OneTargetAnalytics? = nil
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: Const.sdk, binaryMessenger: registrar.messenger())
        let instance = SwiftOneTargetMobileSdkPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
        case Const.getPlatformVersion:
            result("iOS " + UIDevice.current.systemVersion)
        case Const.setupTracking:
            setupTracking(call, result)
        case Const.trackEvent:
            trackEvent(call, result)
        default:
            result(nil)
        }
    }
    
    private func setupTracking(_ call: FlutterMethodCall,_ result: @escaping FlutterResult) {
        let arguments = call.arguments as! Dictionary<String, Any>
        let writeKey = arguments["writeKey"] as! String
        print("writeKey " + writeKey)
        
        let env = arguments["env"] as! Int
        print("env " + env.toString())
        var flavor = "prod"; // default prod
        if(env == ENV_DEV){
            flavor = "dev"
        }else if(env == ENV_STG){
            flavor = "stg"
        }else if(env == ENV_PROD){
            flavor = "prod"
        }
        print("flavor " + flavor)
        
        let configuration = Configuration(writeKey: writeKey, flavor: flavor)
        
        let oneTargetAppPushID = arguments["oneTargetAppPushID"] as! String
        print("oneTargetAppPushID " + oneTargetAppPushID)
        if(  oneTargetAppPushID.isEmpty){
            //do nothing
        }else{
            configuration.oneTargetAppPushID(oneTargetAppPushID)
        }
        
        analytics = OneTargetAnalytics.init(configuration: configuration, withLaunchOptions: nil)
        let debugLogsEnabled = arguments["isShowLog"] as! Bool
        print("debugLogsEnabled " + debugLogsEnabled.toString())
        OneTargetAnalytics.debugLogsEnabled = debugLogsEnabled
        result(true)
    }
    
    //flavor: dev, stg
    private func trackEvent(_ call: FlutterMethodCall,_ result: @escaping FlutterResult) {
        let arguments = call.arguments as! Dictionary<String, Any>
        
        let identityId = arguments["identityId"] as! Dictionary<String, Any>
        print("identityId: \(identityId as AnyObject)")
        let profile = arguments["profile"] as! [Dictionary<String, Any>]
        print("profile: \(profile as AnyObject)")
        let eventName = arguments["eventName"] as! String
        print("eventName " + eventName)
        let eventData = arguments["eventData"] as! Dictionary<String, Any>
        print("eventData: \(eventData as AnyObject)")
        
        let outputPlugin = OutputPlugin()
        outputPlugin.result = result
        analytics?.add(plugin: outputPlugin)
        
        analytics?.trackEvent(
            identityId: identityId,
            eventName: eventName,
            eventData: eventData,
            profile: profile
        )
        
    }
    
    private func convertMilliToDate(milliseconds: Int64) -> Date {
        return Date(timeIntervalSince1970: (TimeInterval(milliseconds) / 1000))
    }
}

class OutputPlugin: Plugin {
    var analytics: OneTargetAnalytics?
    var type: PluginType = .after
    var result:FlutterResult?
    
    func execute<T>(event: T?) -> T? where T : RawEvent {
        
        let string = event?.prettyPrint() ?? ("")
        print("execute string " + string)
        
        self.result?([
            "response" : string
        ])
        
        return event
    }
}
